@@ -1,30 +1,21 @@
 # Copyright 2016 - 2020  Ternaris.
 # SPDX-License-Identifier: AGPL-3.0-only
 
-from marv_node.io import (
-    Abort,
-    create_group,
-    create_stream,
-    get_logger,
-    get_requested,
-    make_file,
-    pull,
-    pull_all,
-    push,
-    set_header,
-)
 from .decorators import InputNameCollision, input, node, select
+from .ioctrl import (Abort, ReaderError, create_group, create_stream, get_logger, get_requested,
+                     get_resource_path, make_file, pull, pull_all, push, set_header)
 from .scanner import DatasetInfo
 
-
 __all__ = (
     'Abort',
     'DatasetInfo',
     'InputNameCollision',
+    'ReaderError',
     'create_group',
     'create_stream',
     'get_logger',
     'get_requested',
+    'get_resource_path',
     'input',
     'make_file',
     'node',
